.. currentmodule:: abjad.tools.scoretools

scale_measure_denominator_and_adjust_measure_contents
=====================================================

.. autofunction:: scale_measure_denominator_and_adjust_measure_contents
